"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasher = void 0;
const sha256_1 = require("@noble/hashes/sha256");
const as_sha256_1 = require("@chainsafe/as-sha256");
const util_1 = require("./util");
const digest64 = (a, b) => sha256_1.sha256.create().update(a).update(b).digest();
const hashInto = (input, output) => {
    if (input.length % 64 !== 0) {
        throw new Error(`Invalid input length ${input.length}`);
    }
    if (input.length !== output.length * 2) {
        throw new Error(`Invalid output length ${output.length}`);
    }
    const count = Math.floor(input.length / 64);
    for (let i = 0; i < count; i++) {
        const offset = i * 64;
        const in1 = input.subarray(offset, offset + 32);
        const in2 = input.subarray(offset + 32, offset + 64);
        const out = digest64(in1, in2);
        output.set(out, i * 32);
    }
};
exports.hasher = {
    name: "noble",
    digest64,
    digest64HashObjects: (left, right, parent) => {
        as_sha256_1.byteArrayIntoHashObject(digest64(util_1.hashObjectToUint8Array(left), util_1.hashObjectToUint8Array(right)), 0, parent);
    },
    merkleizeInto(data, padFor, output, offset) {
        return util_1.doMerkleizeInto(data, padFor, output, offset, hashInto);
    },
    digestNLevel(data, nLevel) {
        return util_1.doDigestNLevel(data, nLevel, hashInto);
    },
    executeHashComputations: (hashComputations) => {
        for (let level = hashComputations.length - 1; level >= 0; level--) {
            const hcArr = hashComputations[level];
            if (!hcArr) {
                // should not happen
                throw Error(`no hash computations for level ${level}`);
            }
            for (const hc of hcArr) {
                hc.dest.applyHash(as_sha256_1.digest64HashObjects(hc.src0, hc.src1));
            }
        }
    },
};
//# sourceMappingURL=noble.js.map